/*
 *  
 *  $Id: parserxmlspanish.h 3963 2011-07-11 14:03:51Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once
#include <api/ientorno.h>
#include <api/icontroladorhl7.h>
#include <api/imodelohl7.h>

class wxXmlNode;

namespace GIL {
	namespace HL7 {
		class ParserXMLSpanish : public GIL::HL7::IXMLIntegrationParser {
		public:
			typedef std::map<std::string, GIL::IModeloPACSServer> MapaServers;

			ParserXMLSpanish();
			~ParserXMLSpanish();
			virtual std::list<std::string> GetKeys();
			virtual void ParseIntegrationXML(GNC::GCS::IEntorno::ListaModelosIntegracion& models, wxXmlNode* pRoot);			
			virtual GIL::IModeloIntegracion* ParsePlantilla(wxXmlNode* pNode, MapaServers& servers);
		protected:
		};
	}
}
